@@ -32,9 +32,7 @@ class DriveFilter(NetBoxModelFilterSet):
             return queryset
         qs_filter = (
             Q(size__icontains=value)
-            | Q(cluster__icontains=value)
             | Q(identifier__icontains=value)
-            | Q(virtual_machine__icontains=value)
             | Q(description__icontains=value)
         )
         return queryset.filter(qs_filter)
