@@ -61,7 +61,7 @@ from netbox_storage.views import (
     LinuxVolumeBulkDeleteView,
     LinuxVolumeView,
     LinuxVolumeDeleteView, VolumeGroupPhysicalVolumeListView, VolumeGroupLogicalVolumeListView, LVMAddSimpleView,
-    LVAddSimpleView,
+    LVAddSimpleView, AddVolume,
 )
 
 app_name = "netbox_storage"
@@ -196,4 +196,5 @@ urlpatterns = [
     #
     path("lvm-simple/add/", LVMAddSimpleView.as_view(), name="lvm_simple_add"),
     path("lv-simple/add/", LVAddSimpleView.as_view(), name="lv_simple_add"),
+    path('lv-add/', AddVolume.as_view(), name="lv_volume_add")
 ]
